@@ -13,7 +13,7 @@ type Link<K, V> = Option<Arc<AtomicPtr<SkipNode<K, V>>>>;
 
 /// A node in the skip list.
 #[derive(Debug)]
-struct SkipNode<K: Ord + Debug, V: Clone> {
+pub struct SkipNode<K: Ord + Debug, V: Clone> {
     /// The key should only be `None` for the `head` node.
     key: Option<K>,
     /// The Value should only be `None` for the `head` node.
@@ -21,6 +21,22 @@ struct SkipNode<K: Ord + Debug, V: Clone> {
     levels: Vec<Link<K, V>>,
 }
 
+/// Public methods
+impl<K: Ord + Debug, V: Clone> SkipNode<K, V> {
+    /// Get an immutable reference to the next node at level 0 if it exists. Otherwise, `None`.
+    pub fn next(&self) -> Option<&SkipNode<K, V>> {
+        self.next_at_level(0)
+    }
+
+    /// Get the key and value stored on this node.
+    ///
+    /// This should always return a key-value pair because the head node is the only node that does
+    /// not have a key or a value.
+    pub fn get_entry(&self) -> (&K, &V) {
+        (self.key.as_ref().unwrap(), self.value.as_ref().unwrap())
+    }
+}
+
 /// Private methods
 impl<K: Ord + Debug, V: Clone> SkipNode<K, V> {
     fn new(key: K, value: V, height: usize) -> Self {
@@ -39,11 +55,6 @@ impl<K: Ord + Debug, V: Clone> SkipNode<K, V> {
         }
     }
 
-    /// Get an immutable reference to the next node at level 0 if it exists. Otherwise, `None`.
-    fn next(&self) -> Option<&SkipNode<K, V>> {
-        self.next_at_level(0)
-    }
-
     /// Get an immutable reference to the next node at the specified level if it exists.
     /// Otherwise, `None`.
     fn next_at_level(&self, level: usize) -> Option<&SkipNode<K, V>> {
@@ -128,7 +139,7 @@ pub struct ConcurrentSkipList<K: Ord + Debug, V: Clone> {
     approximate_mem_usage: AtomicUsize,
 }
 
-// Public methods of SkipList
+/// Public methods
 impl<K: Ord + Debug, V: Clone> ConcurrentSkipList<K, V> {
     /// Create a new skip list.
     ///
@@ -425,7 +436,7 @@ where
     }
 }
 
-// Private methods of SkipList
+/// Private methods
 impl<K: Ord + Debug, V: Clone> ConcurrentSkipList<K, V> {
     /// Return a reference to the head node.
     fn head(&self) -> &SkipNode<K, V> {
